@@ -2,7 +2,7 @@ package Test2::Hub;
 use strict;
 use warnings;
 
-our $VERSION = '1.302198';
+our $VERSION = '1.302204';
 
 
 use Carp qw/carp croak confess/;
@@ -233,8 +233,8 @@ sub add_context_acquire {
 *remove_context_aquire = \&remove_context_acquire;
 sub remove_context_acquire {
     my $self = shift;
-    my %subs = map {$_ => $_} @_;
-    @{$self->{+_CONTEXT_ACQUIRE}} = grep { !$subs{$_} == $_ } @{$self->{+_CONTEXT_ACQUIRE}};
+    my %subs = map {$_ => 1} @_;
+    @{$self->{+_CONTEXT_ACQUIRE}} = grep { !$subs{$_} } @{$self->{+_CONTEXT_ACQUIRE}};
 }
 
 sub add_context_init {
@@ -251,8 +251,8 @@ sub add_context_init {
 
 sub remove_context_init {
     my $self = shift;
-    my %subs = map {$_ => $_} @_;
-    @{$self->{+_CONTEXT_INIT}} = grep { !$subs{$_} == $_ } @{$self->{+_CONTEXT_INIT}};
+    my %subs = map {$_ => 1} @_;
+    @{$self->{+_CONTEXT_INIT}} = grep { !$subs{$_} } @{$self->{+_CONTEXT_INIT}};
 }
 
 sub add_context_release {
@@ -269,8 +269,8 @@ sub add_context_release {
 
 sub remove_context_release {
     my $self = shift;
-    my %subs = map {$_ => $_} @_;
-    @{$self->{+_CONTEXT_RELEASE}} = grep { !$subs{$_} == $_ } @{$self->{+_CONTEXT_RELEASE}};
+    my %subs = map {$_ => 1} @_;
+    @{$self->{+_CONTEXT_RELEASE}} = grep { !$subs{$_} } @{$self->{+_CONTEXT_RELEASE}};
 }
 
 sub send {
@@ -879,7 +879,7 @@ tools, plugins, and other extensions.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/test-more/>.
+L<https://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -899,11 +899,11 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2020 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
