@@ -36,8 +36,9 @@ my $known_start_byte = I8_to_native("\xC5");
 sub requires_extended_utf8($) {
 
     # Returns a boolean as to whether or not the code point parameter fits
-    # into 31 bits, subject to the convention that a negative code point
-    # stands for one that overflows the word size, so won't fit in 31 bits.
+    # into 31 bits (30 on EBCDIC), subject to the convention that a negative
+    # code point stands for one that overflows the word size, so won't fit in
+    # 31 bits.
 
     return shift > $highest_non_extended_utf8_cp;
 }
@@ -485,7 +486,6 @@ my @tests;
               : I8_to_native(
                 "\xff\xa7\xbf\xbf\xbf\xbf\xbf\xbf\xbf\xbf\xbf\xbf\xbf\xbf"),
               0x7FFFFFFFFFFFFFFF,
-              (isASCII) ? 1 : 2,
             ],
             [ "first 64 bit code point",
               (isASCII)
@@ -524,7 +524,6 @@ my @tests;
                     I8_to_native(
                     "\xff\xa0\xa0\xa0\xa0\xa0\xa1\xa0\xa0\xa0\xa0\xa0\xa0\xa0"),
                     0x800000000,
-                      40000000
                 ],
                 [ "requires at least 32 bits",
                     I8_to_native(
@@ -584,7 +583,7 @@ sub flags_to_text($$)
 }
 
 # Possible flag returns from utf8n_to_uvchr_error().  These should have G_,
-# instead of A_, D_, but the prefixes will be used in a a later commit, so
+# instead of A_, D_, but the prefixes will be used in a later commit, so
 # minimize churn by having them here.
 my @utf8n_flags_to_text =  ( qw(
         A_EMPTY
@@ -1191,7 +1190,12 @@ foreach my $test (@tests) {
   # We try various combinations of malformations that can occur
   foreach my $short (0, 1) {
     next if $skip_most_tests && $short;
-    foreach my $unexpected_noncont (0, 1) {
+    # Insert an unexpected non-continuation in every possible position
+    my $unexpected_noncont;
+    for ($unexpected_noncont = $length - $short - 1;
+         $unexpected_noncont > 0;
+         $unexpected_noncont--)
+    {
       next if $skip_most_tests && $unexpected_noncont;
       foreach my $overlong (0, 1) {
         next if $overlong && $skip_most_tests;
@@ -1319,11 +1323,14 @@ foreach my $test (@tests) {
 
           if ($unexpected_noncont) {
 
-              # To force this malformation, change the final continuation
-              # byte into a start byte.
-              my $pos = ($short) ? -2 : -1;
-              substr($this_bytes, $pos, 1) = $known_start_byte;
-              $this_expected_len--;
+              # The overlong tweaking above changes the first bytes to
+              # specified values; we better not override those.
+              next if $overlong;
+
+              # To force this malformation, change a continuation byte into a
+              # start byte.
+              substr($this_bytes, $unexpected_noncont, 1) = $known_start_byte;
+              $this_expected_len = $unexpected_noncont;
           }
 
           # The whole point of a test that is malformed from the beginning
@@ -1415,7 +1422,7 @@ foreach my $test (@tests) {
               $allow_flags |= $::UTF8_ALLOW_OVERFLOW if $malformed_allow_type;
           }
 
-          # And we can create the malformation-related text for the the test
+          # And we can create the malformation-related text for the test
           # names we eventually will generate.
           my $malformations_name = "";
           if (@malformation_names) {
@@ -1552,9 +1559,9 @@ foreach my $test (@tests) {
                   # Test partial character handling, for each byte not a
                   # full character
                   my $did_test_partial = 0;
-                  for (my $j = 1; $j < $this_length - 1; $j++) {
+                  for (my $byte_count = 1; $byte_count < $this_expected_len - 1; $byte_count++) {
                       $did_test_partial = 1;
-                      my $partial = substr($this_bytes, 0, $j);
+                      my $partial = substr($this_bytes, 0, $byte_count);
                       my $ret_should_be;
                       my $comment;
                       if ($disallow_type || $malformations_name) {
@@ -1583,7 +1590,7 @@ foreach my $test (@tests) {
                               $needed_to_tell = $dl if $dl < $needed_to_tell;
                           }
 
-                          if ($j < $needed_to_tell) {
+                          if ($byte_count < $needed_to_tell) {
                               $ret_should_be = 1;
                               $comment .= ", but need $needed_to_tell"
                                         . " bytes to discern:";
@@ -1597,7 +1604,7 @@ foreach my $test (@tests) {
                       undef @warnings_gotten;
 
                       $ret = test_is_utf8_valid_partial_char_flags($partial,
-                                                      $j, $disallow_flags);
+                                                      $byte_count, $disallow_flags);
                       is($ret, $ret_should_be,
                           "    And is_utf8_valid_partial_char_flags("
                           . display_bytes($partial)
