@@ -218,12 +218,25 @@ static const struct body_details bodies_by_type[] = {
       SVt_PVIV, FALSE, NONV, HASARENA,
       FIT_ARENA(0, sizeof(XPVIV) - STRUCT_OFFSET(XPV, xpv_cur)) },
 
+#if NVSIZE > 8 && PTRSIZE < 8 && MEM_ALIGNBYTES > 8
+    /* NV may need strict 16 byte alignment.
+
+       On 64-bit systems the NV ends up aligned despite the hack
+       avoiding allocation of xmg_stash and xmg_u, so only do this
+       for 32-bit systems.
+    */
+    { sizeof(XPVNV),
+      sizeof(XPVNV),
+      0,
+      SVt_PVNV, FALSE, HADNV, HASARENA,
+      FIT_ARENA(0, sizeof(XPVNV)) },
+#else
     { sizeof(XPVNV) - STRUCT_OFFSET(XPV, xpv_cur),
       copy_length(XPVNV, xnv_u) - STRUCT_OFFSET(XPV, xpv_cur),
       + STRUCT_OFFSET(XPV, xpv_cur),
       SVt_PVNV, FALSE, HADNV, HASARENA,
       FIT_ARENA(0, sizeof(XPVNV) - STRUCT_OFFSET(XPV, xpv_cur)) },
-
+#endif
     { sizeof(XPVMG), copy_length(XPVMG, xnv_u), 0, SVt_PVMG, FALSE, HADNV,
       HASARENA, FIT_ARENA(0, sizeof(XPVMG)) },
 
@@ -754,9 +767,9 @@ Perl_SvPADSTALE_off(SV *sv)
 
 /*
 =for apidoc_section $SV
-=for apidoc      SvIV
-=for apidoc_item SvIV_nomg
-=for apidoc_item SvIVx
+=for apidoc         SvIV
+=for apidoc_item    SvIV_nomg
+=for apidoc_item m||SvIVx
 
 These each coerce the given SV to IV and return it.  The returned value in many
 circumstances will get stored in C<sv>'s IV slot, but not in all cases.  (Use
@@ -769,9 +782,9 @@ guaranteed to evaluate C<sv> only once.
 
 C<SvIV_nomg> is the same as C<SvIV>, but does not perform 'get' magic.
 
-=for apidoc      SvNV
-=for apidoc_item SvNV_nomg
-=for apidoc_item SvNVx
+=for apidoc         SvNV
+=for apidoc_item    SvNV_nomg
+=for apidoc_item m||SvNVx
 
 These each coerce the given SV to NV and return it.  The returned value in many
 circumstances will get stored in C<sv>'s NV slot, but not in all cases.  (Use
@@ -784,9 +797,9 @@ guaranteed to evaluate C<sv> only once.
 
 C<SvNV_nomg> is the same as C<SvNV>, but does not perform 'get' magic.
 
-=for apidoc      SvUV
-=for apidoc_item SvUV_nomg
-=for apidoc_item SvUVx
+=for apidoc         SvUV
+=for apidoc_item    SvUV_nomg
+=for apidoc_item m||SvUVx
 
 These each coerce the given SV to UV and return it.  The returned value in many
 circumstances will get stored in C<sv>'s UV slot, but not in all cases.  (Use
